@@ -63,7 +63,7 @@ postinstall()   { : ; }
 
 # set version in a way that Makefile.PL can extract
 VERSION=VERSION; eval \
-$VERSION=0.2
+$VERSION=0.9
 
 BZ2=bz2
 BZIP2=bzip2
@@ -432,6 +432,11 @@ EOF
             bundle --perl "$@"
             exit
             ;;
+         mkapp )
+            ( install )
+            bundle --app "$@"
+            exit
+            ;;
          help )
             podusage 2
             ;;
